@@ -18,7 +18,8 @@ namespace dxvk {
   }
 
   D3D9StateBlock::~D3D9StateBlock() {
-    m_parent->DecrementLosableCounter();
+    if (!m_parent->IsD3D8Compatible())
+      m_parent->DecrementLosableCounter();
   }
 
   HRESULT STDMETHODCALLTYPE D3D9StateBlock::QueryInterface(
@@ -48,7 +49,7 @@ namespace dxvk {
     if (m_captures.flags.test(D3D9CapturedStateFlag::VertexDecl))
       SetVertexDeclaration(m_deviceState->vertexDecl.ptr());
 
-    ApplyOrCapture<D3D9StateFunction::Capture>();
+    ApplyOrCapture<D3D9StateFunction::Capture, true>();
 
     return D3D_OK;
   }
@@ -60,7 +61,7 @@ namespace dxvk {
     if (m_captures.flags.test(D3D9CapturedStateFlag::VertexDecl) && m_state.vertexDecl != nullptr)
       m_parent->SetVertexDeclaration(m_state.vertexDecl.ptr());
 
-    ApplyOrCapture<D3D9StateFunction::Apply>();
+    ApplyOrCapture<D3D9StateFunction::Apply, false>();
     m_applying = false;
 
     return D3D_OK;
@@ -121,6 +122,20 @@ namespace dxvk {
   }
 
 
+  HRESULT D3D9StateBlock::SetStreamSourceWithoutOffset(
+          UINT                StreamNumber,
+          D3D9VertexBuffer*   pStreamData,
+          UINT                Stride) {
+    m_state.vertexBuffers[StreamNumber].vertexBuffer = pStreamData;
+
+    m_state.vertexBuffers[StreamNumber].stride = Stride;
+
+    m_captures.flags.set(D3D9CapturedStateFlag::VertexBuffers);
+    m_captures.vertexBuffers.set(StreamNumber, true);
+    return D3D_OK;
+  }
+
+
   HRESULT D3D9StateBlock::SetStreamSourceFreq(UINT StreamNumber, UINT Setting) {
     m_state.streamFreq[StreamNumber] = Setting;
 
@@ -571,8 +586,12 @@ namespace dxvk {
       m_captures.flags.set(D3D9CapturedStateFlag::Material);
     }
 
-    if (Type != D3D9StateBlockType::None)
-      this->Capture();
+    if (Type != D3D9StateBlockType::None) {
+      if (m_captures.flags.test(D3D9CapturedStateFlag::VertexDecl))
+        SetVertexDeclaration(m_deviceState->vertexDecl.ptr());
+
+      ApplyOrCapture<D3D9StateFunction::Capture, false>();
+    }
   }
 
-}
\ No newline at end of file
+}
