@@ -18,10 +18,51 @@
 namespace dxvk {
 
   class D3D9Surface;
+  class D3D9SwapChainEx;
+
+  class D3D9VkExtSwapchain final : public ID3D9VkExtSwapchain {
+  public:
+    D3D9VkExtSwapchain(D3D9SwapChainEx *pSwapChain);
+    
+    ULONG STDMETHODCALLTYPE AddRef();
+    
+    ULONG STDMETHODCALLTYPE Release();
+    
+    HRESULT STDMETHODCALLTYPE QueryInterface(
+            REFIID                  riid,
+            void**                  ppvObject);
+
+    BOOL STDMETHODCALLTYPE CheckColorSpaceSupport(
+            VkColorSpaceKHR           ColorSpace);
+
+    HRESULT STDMETHODCALLTYPE SetColorSpace(
+            VkColorSpaceKHR           ColorSpace);
+
+    HRESULT STDMETHODCALLTYPE SetHDRMetaData(
+      const VkHdrMetadataEXT          *pHDRMetadata);
+
+    HRESULT STDMETHODCALLTYPE GetCurrentOutputDesc(
+            D3D9VkExtOutputMetadata   *pOutputDesc);
+
+    void STDMETHODCALLTYPE UnlockAdditionalFormats();
+
+  private:
+    D3D9SwapChainEx *m_swapchain;
+  };
+
+  struct D3D9WindowContext {
+    Rc<Presenter>                  presenter;
+    std::vector<Rc<DxvkImageView>> imageViews;
+
+    uint64_t                       frameId = D3D9DeviceEx::MaxFrameLatency;
+    Rc<sync::Fence>                frameLatencySignal;
+  };
 
   using D3D9SwapChainExBase = D3D9DeviceChild<IDirect3DSwapChain9Ex>;
   class D3D9SwapChainEx final : public D3D9SwapChainExBase {
     static constexpr uint32_t NumControlPoints = 256;
+
+    friend class D3D9VkExtSwapchain;
   public:
 
     D3D9SwapChainEx(
@@ -85,6 +126,14 @@ namespace dxvk {
 
     void SyncFrameLatency();
 
+    bool HasFormatsUnlocked() const { return m_unlockAdditionalFormats; }
+
+    void DestroyBackBuffers();
+
+    void SetApiName(const char* name);
+
+    void UpdateWindowCtx();
+
   private:
 
     enum BindingIds : uint32_t {
@@ -99,7 +148,11 @@ namespace dxvk {
     Rc<DxvkContext>           m_context;
     Rc<DxvkSwapchainBlitter>  m_blitter;
 
-    Rc<vk::Presenter>         m_presenter;
+    std::unordered_map<
+      HWND,
+      D3D9WindowContext>      m_presenters;
+
+    D3D9WindowContext*        m_wctx = nullptr;
 
     Rc<hud::Hud>              m_hud;
 
@@ -112,17 +165,10 @@ namespace dxvk {
 
     DxvkSubmitStatus          m_presentStatus;
 
-    std::vector<Rc<DxvkImageView>> m_imageViews;
-
-
-    uint64_t                  m_frameId           = D3D9DeviceEx::MaxFrameLatency;
-    uint32_t                  m_frameLatencyCap   = 0;
-    Rc<sync::Fence>           m_frameLatencySignal;
+    uint32_t                  m_frameLatencyCap = 0;
 
     bool                      m_dirty    = true;
-    bool                      m_vsync    = true;
-
-    bool                      m_dialog;
+    bool                      m_dialog   = false;
     bool                      m_lastDialog = false;
 
     HWND                      m_window   = nullptr;
@@ -132,16 +178,25 @@ namespace dxvk {
 
     double                    m_displayRefreshRate = 0.0;
 
+    const char*               m_apiName  = nullptr;
+
     bool                      m_warnedAboutGDIFallback = false;
 
+    VkColorSpaceKHR           m_colorspace = VK_COLOR_SPACE_SRGB_NONLINEAR_KHR;
+
+    std::optional<VkHdrMetadataEXT> m_hdrMetadata;
+    bool m_dirtyHdrMetadata = true;
+    bool m_unlockAdditionalFormats = false;
+
+    D3D9VkExtSwapchain m_swapchainExt;
+
     void PresentImage(UINT PresentInterval);
 
-    void SubmitPresent(const vk::PresenterSync& Sync, uint32_t FrameId);
+    void SubmitPresent(const PresenterSync& Sync, uint32_t Repeat);
 
     void SynchronizePresent();
 
-    void RecreateSwapChain(
-        BOOL                      Vsync);
+    void RecreateSwapChain();
 
     void CreatePresenter();
 
@@ -149,8 +204,6 @@ namespace dxvk {
 
     void CreateRenderTargetViews();
 
-    void DestroyBackBuffers();
-
     HRESULT CreateBackBuffers(
             uint32_t            NumBackBuffers);
 
@@ -160,16 +213,14 @@ namespace dxvk {
 
     void InitRamp();
 
+    void UpdateTargetFrameRate(uint32_t SyncInterval);
+
     uint32_t GetActualFrameLatency();
 
     uint32_t PickFormats(
             D3D9Format                Format,
             VkSurfaceFormatKHR*       pDstFormats);
     
-    uint32_t PickPresentModes(
-            BOOL                      Vsync,
-            VkPresentModeKHR*         pDstModes);
-    
     uint32_t PickImageCount(
             UINT                      Preferred);
 
