@@ -33,9 +33,13 @@ namespace dxvk {
     /// Emulate UMA
     bool emulateUMA;
 
-    /// Reports Nvidia GPUs as a different vendor (usually AMD)
+    /// Reports Nvidia GPUs running on the proprietary driver as a different
+    /// vendor (usually AMD). Proton will generally disable this option.
     bool hideNvidiaGpu;
 
+    /// Reports Nvidia GPUs running on NVK as a different vendor (usually AMD)
+    bool hideNvkGpu;
+
     /// Reports AMD GPUs as a different vendor (usually Nvidia)
     bool hideAmdGpu;
 
@@ -44,6 +48,13 @@ namespace dxvk {
 
     /// Enable HDR
     bool enableHDR;
+
+    /// Limit frame rate
+    int32_t maxFrameRate;
+
+    /// Sync interval. Overrides the value
+    /// passed to IDXGISwapChain::Present.
+    int32_t syncInterval;
   };
   
 }
