@@ -25,6 +25,9 @@ namespace dxvk {
     // Query updated interface versions from presenter, this
     // may fail e.g. with older vkd3d-proton builds.
     m_presenter->QueryInterface(__uuidof(IDXGIVkSwapChain1), reinterpret_cast<void**>(&m_presenter1));
+    m_presenter->QueryInterface(__uuidof(IDXGIVkSwapChain2), reinterpret_cast<void**>(&m_presenter2));
+
+    m_frameRateOption = m_factory->GetOptions()->maxFrameRate;
 
     // Query monitor info form DXVK's DXGI factory, if available
     m_factory->QueryInterface(__uuidof(IDXGIVkMonitorInfo), reinterpret_cast<void**>(&m_monitorInfo));
@@ -32,6 +35,9 @@ namespace dxvk {
     // Apply initial window mode and fullscreen state
     if (!m_descFs.Windowed && FAILED(EnterFullscreenMode(nullptr)))
       throw DxvkError("DXGI: Failed to set initial fullscreen state");
+
+    // Ensure that RGBA16 swap chains are scRGB if supported
+    UpdateColorSpace(m_desc.Format, m_colorSpace);
   }
   
   
@@ -300,19 +306,32 @@ namespace dxvk {
   
   
   HRESULT STDMETHODCALLTYPE DxgiSwapChain::Present(UINT SyncInterval, UINT Flags) {
-    return Present1(SyncInterval, Flags, nullptr);
+    return PresentBase(SyncInterval, Flags, nullptr);
   }
-  
-  
+
   HRESULT STDMETHODCALLTYPE DxgiSwapChain::Present1(
           UINT                      SyncInterval,
           UINT                      PresentFlags,
     const DXGI_PRESENT_PARAMETERS*  pPresentParameters) {
 
+    return PresentBase(SyncInterval, PresentFlags, pPresentParameters);
+  }
+
+  HRESULT STDMETHODCALLTYPE DxgiSwapChain::PresentBase(
+          UINT                      SyncInterval,
+          UINT                      PresentFlags,
+    const DXGI_PRESENT_PARAMETERS*  pPresentParameters) {
+
     if (SyncInterval > 4)
       return DXGI_ERROR_INVALID_CALL;
 
+    auto options = m_factory->GetOptions();
+
+    if (options->syncInterval >= 0)
+      SyncInterval = options->syncInterval;
+
     UpdateGlobalHDRState();
+    UpdateTargetFrameRate(SyncInterval);
 
     std::lock_guard<dxvk::recursive_mutex> lockWin(m_lockWindow);
     HRESULT hr = S_OK;
@@ -393,7 +412,13 @@ namespace dxvk {
     if (Format != DXGI_FORMAT_UNKNOWN)
       m_desc.Format = Format;
     
-    return m_presenter->ChangeProperties(&m_desc, pCreationNodeMask, ppPresentQueue);
+    HRESULT hr = m_presenter->ChangeProperties(&m_desc, pCreationNodeMask, ppPresentQueue);
+
+    if (FAILED(hr))
+      return hr;
+
+    UpdateColorSpace(m_desc.Format, m_colorSpace);
+    return hr;
   }
 
 
@@ -435,9 +460,7 @@ namespace dxvk {
         return E_FAIL;
       }
       
-      // If the swap chain allows it, change the display mode
-      if (m_desc.Flags & DXGI_SWAP_CHAIN_FLAG_ALLOW_MODE_SWITCH)
-        ChangeDisplayMode(output.ptr(), &newDisplayMode);
+      ChangeDisplayMode(output.ptr(), &newDisplayMode);
 
       wsi::updateFullscreenWindow(m_monitor, m_window, false);
     }
@@ -567,36 +590,31 @@ namespace dxvk {
     if (!pColorSpaceSupport)
       return E_INVALIDARG;
 
-    // Don't expose any color spaces other than standard
-    // sRGB if the enableHDR option is not set.
-    //
-    // If we ever have a use for the non-SRGB non-HDR colorspaces
-    // some day, we may want to revisit this.
-    if (ColorSpace != DXGI_COLOR_SPACE_RGB_FULL_G22_NONE_P709
-     && !m_factory->GetOptions()->enableHDR) {
+    std::lock_guard<dxvk::mutex> lock(m_lockBuffer);
+
+    if (ValidateColorSpaceSupport(m_desc.Format, ColorSpace))
+      *pColorSpaceSupport = DXGI_SWAP_CHAIN_COLOR_SPACE_SUPPORT_FLAG_PRESENT;
+    else
       *pColorSpaceSupport = 0;
-      return S_OK;
-    }
 
-    UINT support = m_presenter->CheckColorSpaceSupport(ColorSpace);
-    *pColorSpaceSupport = support;
     return S_OK;
   }
 
 
   HRESULT STDMETHODCALLTYPE DxgiSwapChain::SetColorSpace1(DXGI_COLOR_SPACE_TYPE ColorSpace) {
-    UINT support = m_presenter->CheckColorSpaceSupport(ColorSpace);
+    std::lock_guard<dxvk::mutex> lock(m_lockBuffer);
 
-    if (!support)
+    if (!ValidateColorSpaceSupport(m_desc.Format, ColorSpace))
       return E_INVALIDARG;
 
-    std::lock_guard<dxvk::mutex> lock(m_lockBuffer);
-    HRESULT hr = m_presenter->SetColorSpace(ColorSpace);
-    if (SUCCEEDED(hr)) {
-      // If this was a colorspace other than our current one,
-      // punt us into that one on the DXGI output.
-      m_monitorInfo->PuntColorSpace(ColorSpace);
-    }
+    // Write back color space if setting it up succeeded. This way, we preserve
+    // the current color space even if the swap chain temporarily switches to a
+    // back buffer format which does not support it.
+    HRESULT hr = UpdateColorSpace(m_desc.Format, ColorSpace);
+
+    if (SUCCEEDED(hr))
+      m_colorSpace = ColorSpace;
+
     return hr;
   }
 
@@ -652,35 +670,33 @@ namespace dxvk {
       }
     }
 
-    const bool modeSwitch = m_desc.Flags & DXGI_SWAP_CHAIN_FLAG_ALLOW_MODE_SWITCH;
+    DXGI_MODE_DESC1 displayMode = { };
+    displayMode.Width            = m_desc.Width;
+    displayMode.Height           = m_desc.Height;
+    displayMode.RefreshRate      = m_descFs.RefreshRate;
+    displayMode.Format           = m_desc.Format;
+    // Ignore these two, games usually use them wrong and we don't
+    // support any scaling modes except UNSPECIFIED anyway.
+    displayMode.ScanlineOrdering = DXGI_MODE_SCANLINE_ORDER_UNSPECIFIED;
+    displayMode.Scaling          = DXGI_MODE_SCALING_UNSPECIFIED;
     
-    if (modeSwitch) {
-      DXGI_MODE_DESC1 displayMode = { };
-      displayMode.Width            = m_desc.Width;
-      displayMode.Height           = m_desc.Height;
-      displayMode.RefreshRate      = m_descFs.RefreshRate;
-      displayMode.Format           = m_desc.Format;
-      // Ignore these two, games usually use them wrong and we don't
-      // support any scaling modes except UNSPECIFIED anyway.
-      displayMode.ScanlineOrdering = DXGI_MODE_SCANLINE_ORDER_UNSPECIFIED;
-      displayMode.Scaling          = DXGI_MODE_SCALING_UNSPECIFIED;
-      
-      if (FAILED(ChangeDisplayMode(output.ptr(), &displayMode))) {
-        Logger::err("DXGI: EnterFullscreenMode: Failed to change display mode");
-        return DXGI_ERROR_NOT_CURRENTLY_AVAILABLE;
-      }
+    if (FAILED(ChangeDisplayMode(output.ptr(), &displayMode))) {
+      Logger::err("DXGI: EnterFullscreenMode: Failed to change display mode");
+      return DXGI_ERROR_NOT_CURRENTLY_AVAILABLE;
     }
     
     // Update swap chain description
     m_descFs.Windowed = FALSE;
     
     // Move the window so that it covers the entire output
+    bool modeSwitch = (m_desc.Flags & DXGI_SWAP_CHAIN_FLAG_ALLOW_MODE_SWITCH) != 0u;
+
     DXGI_OUTPUT_DESC desc;
     output->GetDesc(&desc);
 
     if (!wsi::enterFullscreenMode(desc.Monitor, m_window, &m_windowState, modeSwitch)) {
-        Logger::err("DXGI: EnterFullscreenMode: Failed to enter fullscreen mode");
-        return DXGI_ERROR_NOT_CURRENTLY_AVAILABLE;
+      Logger::err("DXGI: EnterFullscreenMode: Failed to enter fullscreen mode");
+      return DXGI_ERROR_NOT_CURRENTLY_AVAILABLE;
     }
     
     m_monitor = desc.Monitor;
@@ -744,14 +760,19 @@ namespace dxvk {
     pOutput->GetDesc(&outputDesc);
     
     DXGI_MODE_DESC1 preferredMode = *pDisplayMode;
-    DXGI_MODE_DESC1 selectedMode;
+    DXGI_MODE_DESC1 selectedMode = { };
+
+    if (!(m_desc.Flags & DXGI_SWAP_CHAIN_FLAG_ALLOW_MODE_SWITCH)) {
+      preferredMode.Width = 0;
+      preferredMode.Height = 0;
+    }
 
     if (preferredMode.Format == DXGI_FORMAT_UNKNOWN)
       preferredMode.Format = m_desc.Format;
     
     HRESULT hr = pOutput->FindClosestMatchingMode1(
       &preferredMode, &selectedMode, nullptr);
-    
+
     if (FAILED(hr)) {
       Logger::err(str::format(
         "DXGI: Failed to query closest mode:",
@@ -761,6 +782,9 @@ namespace dxvk {
       return hr;
     }
 
+    if (!selectedMode.RefreshRate.Denominator)
+      selectedMode.RefreshRate.Denominator = 1;
+
     if (!wsi::setWindowMode(outputDesc.Monitor, m_window, ConvertDisplayMode(selectedMode)))
       return DXGI_ERROR_NOT_CURRENTLY_AVAILABLE;
 
@@ -782,6 +806,8 @@ namespace dxvk {
       ReleaseMonitorData();
     }
 
+    m_frameRateRefresh = double(selectedMode.RefreshRate.Numerator)
+                       / double(selectedMode.RefreshRate.Denominator);
     return S_OK;
   }
   
@@ -793,6 +819,7 @@ namespace dxvk {
     if (!wsi::restoreDisplayMode())
       return DXGI_ERROR_NOT_CURRENTLY_AVAILABLE;
 
+    m_frameRateRefresh = 0.0;
     return S_OK;
   }
   
@@ -864,6 +891,7 @@ namespace dxvk {
       m_monitorInfo->ReleaseMonitorData();
   }
 
+
   void DxgiSwapChain::UpdateGlobalHDRState() {
     // Update the global HDR state if called from the legacy NVAPI
     // interfaces, etc.
@@ -888,4 +916,70 @@ namespace dxvk {
     }
   }
 
+
+  bool DxgiSwapChain::ValidateColorSpaceSupport(
+          DXGI_FORMAT             Format,
+          DXGI_COLOR_SPACE_TYPE   ColorSpace) {
+    // RGBA16 swap chains are treated as scRGB even on SDR displays,
+    // and regular sRGB is not exposed when this format is used.
+    if (Format == DXGI_FORMAT_R16G16B16A16_FLOAT)
+      return ColorSpace == DXGI_COLOR_SPACE_RGB_FULL_G10_NONE_P709;
+
+    // For everything else, we will always expose plain sRGB
+    if (ColorSpace == DXGI_COLOR_SPACE_RGB_FULL_G22_NONE_P709)
+      return true;
+
+    // Only expose HDR10 color space if HDR option is enabled
+    if (ColorSpace == DXGI_COLOR_SPACE_RGB_FULL_G2084_NONE_P2020)
+      return m_factory->GetOptions()->enableHDR && m_presenter->CheckColorSpaceSupport(ColorSpace);
+
+    return false;
+  }
+
+
+  HRESULT DxgiSwapChain::UpdateColorSpace(
+          DXGI_FORMAT             Format,
+          DXGI_COLOR_SPACE_TYPE   ColorSpace) {
+    // Don't do anything if the explicitly sepected color space
+    // is compatible with the back buffer format already
+    if (!ValidateColorSpaceSupport(Format, ColorSpace)) {
+      ColorSpace = Format == DXGI_FORMAT_R16G16B16A16_FLOAT
+        ? DXGI_COLOR_SPACE_RGB_FULL_G10_NONE_P709
+        : DXGI_COLOR_SPACE_RGB_FULL_G22_NONE_P709;
+    }
+
+    // Ensure that we pick a supported color space. This is relevant for
+    // mapping scRGB to sRGB on SDR setups, matching Windows behaviour.
+    if (!m_presenter->CheckColorSpaceSupport(ColorSpace))
+      ColorSpace = DXGI_COLOR_SPACE_RGB_FULL_G22_NONE_P709;
+
+    HRESULT hr = m_presenter->SetColorSpace(ColorSpace);
+
+    // If this was a colorspace other than our current one,
+    // punt us into that one on the DXGI output.
+    if (SUCCEEDED(hr))
+      m_monitorInfo->PuntColorSpace(ColorSpace);
+
+    return hr;
+  }
+
+
+  void DxgiSwapChain::UpdateTargetFrameRate(
+          UINT                    SyncInterval) {
+    if (m_presenter2 == nullptr)
+      return;
+
+    // Use a negative number to indicate that the limiter should only
+    // be engaged if the target frame rate is actually exceeded
+    double frameRate = std::max(m_frameRateOption, 0.0);
+
+    if (SyncInterval && m_frameRateOption == 0.0)
+      frameRate = -m_frameRateRefresh / double(SyncInterval);
+
+    if (m_frameRateLimit != frameRate) {
+      m_frameRateLimit = frameRate;
+      m_presenter2->SetTargetFrameRate(frameRate);
+    }
+  }
+
 }
