@@ -187,12 +187,19 @@ namespace dxvk {
 
     Com<IDXGIVkSwapChain>           m_presenter;
     Com<IDXGIVkSwapChain1>          m_presenter1;
+    Com<IDXGIVkSwapChain2>          m_presenter2;
     
     HMONITOR                        m_monitor;
     bool                            m_monitorHasOutput = true;
     bool                            m_frameStatisticsDisjoint = true;
     wsi::DxvkWindowState            m_windowState;
 
+    double                          m_frameRateOption = 0.0;
+    double                          m_frameRateRefresh = 0.0;
+    double                          m_frameRateLimit = 0.0;
+
+    DXGI_COLOR_SPACE_TYPE           m_colorSpace = DXGI_COLOR_SPACE_RGB_FULL_G22_NONE_P709;
+
     uint32_t                        m_globalHDRStateSerial = 0;
     
     HRESULT EnterFullscreenMode(
@@ -223,6 +230,21 @@ namespace dxvk {
 
     void UpdateGlobalHDRState();
 
+    bool ValidateColorSpaceSupport(
+            DXGI_FORMAT             Format,
+            DXGI_COLOR_SPACE_TYPE   ColorSpace);
+
+    HRESULT UpdateColorSpace(
+            DXGI_FORMAT             Format,
+            DXGI_COLOR_SPACE_TYPE   ColorSpace);
+
+    void UpdateTargetFrameRate(
+            UINT                    SyncInterval);
+
+    HRESULT STDMETHODCALLTYPE PresentBase(
+            UINT                      SyncInterval,
+            UINT                      PresentFlags,
+      const DXGI_PRESENT_PARAMETERS*  pPresentParameters);
   };
   
 }
