@@ -36,6 +36,14 @@ namespace dxvk {
     /// Forces swap chain into MAILBOX (if true)
     /// or FIFO_RELAXED (if false) present mode
     Tristate tearFree;
+
+    // Hides integrated GPUs if dedicated GPUs are
+    // present. May be necessary for some games that
+    // incorrectly assume monitor layouts.
+    bool hideIntegratedGraphics;
+
+    // Device name
+    std::string deviceFilter;
   };
 
 }
